==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Tất cả font</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Hệ thông</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Tài khoản</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Yêu thích</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Kích hoạt</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Trung Quốc</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospaced</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>File lỗi</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Giống với phiên bản đã được cài đặt</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Font hệ thống</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Phông</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 phông đã được cài đặt</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 phông đã cài dặt</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Bạn có muốn xóa phông này không?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Phông này không có sẵn cho các ứng dụng</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Những phông chữ này sẽ không có sẵn cho các ứng dụng</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Đang xóa phông, vui lòng đợi...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Xác minh phông chữ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Không có phông nào được cài đặt</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Đừng để giấc mơ của bạn là giấc mơ</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Thông tin cơ bản</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Giao diện</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Loại</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Phiên bản</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Mô tả</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Chưa xác định</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Họ tên đầy đủ</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Thương hiệu</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Quản lý Font</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Quản lý phông giúp người dùng cài đặt và quản lý phông</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Đang tải phông, vui lòng đợi...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Các phông đã được xuất ra ngoài màn hình chính</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>Phông %1 đã được xuất ra ngoài màn hình chính</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Không xuất được 1 phông, không đủ bộ nhớ</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Không xuất được %1 phông, không đủ bộ nhớ</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Thêm phông</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Bật</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Yêu thích</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Không thích</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Chi tiết</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Hiển thị ở Quản lý file</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Xuất</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>bỏ kích hoạt</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Phông đã bị tắt</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Một số phông chữ không được phép vô hiệu hóa</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Cài dặt phông</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Đang xác thực...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Chưa xác định</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>File lỗi</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Đã cài đặt</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Không cài dặt</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Cài dặt phông</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Không có kết quả</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Không có phông</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hỗ trợ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Hiển thị shortcut</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Thêm phông</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Yêu thích</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Không thích</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Thông tin phông</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Nhập thử chữ xem trước</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>File lỗi</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Tất cả font</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Hệ thông</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Tài khoản</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Yêu thích</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Kích hoạt</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Trung Quốc</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospaced</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Hủy</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Bật</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Tắt</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>File lỗi</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Giống với phiên bản đã được cài đặt</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Font hệ thống</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 phông đã được cài đặt</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 phông đã cài dặt</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Không cài được %1 phông . Không đủ bộ nhớ</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Phông này không có sẵn cho các ứng dụng</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Những phông chữ này sẽ không có sẵn cho các ứng dụng</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Đang xóa phông, vui lòng đợi...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Xác minh phông chữ</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Không có phông nào được cài đặt</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Thoát</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Tiếp tục</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Thông tin cơ bản</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Giao diện</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Loại</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Phiên bản</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Mô tả</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Chưa xác định</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Họ tên đầy đủ</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Thương hiệu</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Quản lý Font</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Quản lý phông giúp người dùng cài đặt và quản lý phông</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Đang tải phông, vui lòng đợi...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Các phông đã được xuất ra ngoài màn hình chính</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>Phông %1 đã được xuất ra ngoài màn hình chính</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Không xuất được 1 phông, không đủ bộ nhớ</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Không xuất được %1 phông, không đủ bộ nhớ</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Thêm phông</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Bật</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Yêu thích</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Không thích</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Chi tiết</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Hiển thị ở Quản lý file</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Xuất</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>bỏ kích hoạt</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Phông đã bị tắt</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Cài dặt phông</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Đang xác thực...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Chưa xác định</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>File lỗi</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Đã cài đặt</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Không cài dặt</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Cài dặt phông</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Không có kết quả</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Không có phông</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hỗ trợ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Hiển thị shortcut</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Thêm phông</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Yêu thích</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Không thích</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Thông tin phông</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Nhập thử chữ xem trước</translation>
    </message>
</context>
</TS>
